@@ -227,7 +227,10 @@ class Say(object):
         cloned.options = self.options.push(kwargs)
         return cloned
 
-    def __call__(self, *args, **kwargs): 
+    def __call__(self, *args, **kwargs):
+        """
+        Primary interface. say(something)
+        """
         
         opts = self.options.push(kwargs)
         if not opts._callframe:
@@ -236,7 +239,20 @@ class Say(object):
         formatted = [ _sprintf(arg, opts._callframe) if is_string(arg) else str(arg)
                       for arg in args ]
         return self._output(opts.sep.join(formatted), opts)
+
+    def __gt__(self, arg):
+        """
+        Simple, non-functional call.  EXPERIMENTAL. Based on Python order of
+        operator precedence, probably not all that valuable.
+        """
         
+        opts = self.options.push({})
+        opts._callframe = inspect.currentframe().f_back
+        
+        formatted = [ _sprintf(arg, opts._callframe) if is_string(arg) else str(arg) ]
+        return self._output(opts.sep.join(formatted), opts)
+
+  
     def _output(self, data, opts):
         """
         Do the actual formatting and outputting work. ``data`` may be either a
